==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebTabHeaderElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescriptionMetadata } from "./WebDragServiceDescriptionMetadata";
import { WebTabHeaderElementDescription } from "./WebTabHeaderElementDescription";
/**
 * @hidden
 */
export let WebTabHeaderElementDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabHeaderElementDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabHeaderElementDescriptionMetadata.a == null) {
                WebTabHeaderElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabHeaderElementDescriptionMetadata.c(WebTabHeaderElementDescriptionMetadata.a);
            }
            if (a.j(WebTabHeaderElementDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTabHeaderElementDescriptionMetadata.a);
            WebDragServiceDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabHeaderElement");
            a.item("DragService", "ExportedType:WebDragService");
        }
        static d(a) {
            WebTabHeaderElementDescriptionMetadata.b(a);
            a.aa("WebTabHeaderElement", () => new WebTabHeaderElementDescription());
            a.z("WebTabHeaderElement", WebTabHeaderElementDescriptionMetadata.a);
        }
    }
    WebTabHeaderElementDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabHeaderElementDescriptionMetadata, 'WebTabHeaderElementDescriptionMetadata');
    WebTabHeaderElementDescriptionMetadata.a = null;
    return WebTabHeaderElementDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebTabHeaderElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescriptionMetadata } from "./WebDragServiceDescriptionMetadata";
import { WebTabHeaderElementDescription } from "./WebTabHeaderElementDescription";
/**
 * @hidden
 */
export let WebTabHeaderElementDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabHeaderElementDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabHeaderElementDescriptionMetadata.a == null) {
                WebTabHeaderElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabHeaderElementDescriptionMetadata.c(WebTabHeaderElementDescriptionMetadata.a);
            }
            if (a.k(WebTabHeaderElementDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebTabHeaderElementDescriptionMetadata.a);
            WebDragServiceDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabHeaderElement");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("DragService", "ExportedType:WebDragService");
        }
        static d(a) {
            WebTabHeaderElementDescriptionMetadata.b(a);
            a.ac("WebTabHeaderElement", () => new WebTabHeaderElementDescription());
            a.ab("WebTabHeaderElement", WebTabHeaderElementDescriptionMetadata.a);
        }
    }
    WebTabHeaderElementDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabHeaderElementDescriptionMetadata, 'WebTabHeaderElementDescriptionMetadata');
    WebTabHeaderElementDescriptionMetadata.a = null;
    return WebTabHeaderElementDescriptionMetadata;
})();
